summary refs log tree commit diff
diff options
context:
space:
mode:
authorAzrenbeth <7782548+Azrenbeth@users.noreply.github.com>2021-09-28 17:07:11 +0100
committerAzrenbeth <7782548+Azrenbeth@users.noreply.github.com>2021-09-28 17:16:23 +0100
commit1a50b18994707c17f1cd82bc2283689d2b09b0b9 (patch)
treecb53bbe998799ef1c98375c36d4253f2bc702f53
parentMake the looping call wait until the previous run has finished (diff)
downloadsynapse-1a50b18994707c17f1cd82bc2283689d2b09b0b9.tar.xz
Update name to 'synapse_auto_compressor'
-rw-r--r--docs/state_compressor.md6
-rw-r--r--synapse/config/state_compressor.py2
-rw-r--r--synapse/python_dependencies.py2
-rw-r--r--synapse/util/state_compressor.py4
4 files changed, 7 insertions, 7 deletions
diff --git a/docs/state_compressor.md b/docs/state_compressor.md
index 56f21a03cd..6ced810640 100644
--- a/docs/state_compressor.md
+++ b/docs/state_compressor.md
@@ -6,8 +6,8 @@ can be found on [its github repository](https://github.com/matrix-org/rust-synap
 
 ## Enabling the state compressor
 
-The state compressor requires the python library for the `auto_compressor` tool to be 
-installed. Instructions for this can be found in [the `python.md` file in the source
+The state compressor requires the python library for the `synapse_auto_compressor` tool to be 
+installed. This can be done with pip or by following the instructions for this can be found in [the `python.md` file in the source
 repo](https://github.com/matrix-org/rust-synapse-compress-state/blob/main/docs/python.md).
 
 The following configuration options are provided:
@@ -41,7 +41,7 @@ An example configuration:
 state_compressor:
     enabled: true
     chunk_size: 500
-    number_of_chunks: 5
+    number_of_chunks: 50
     default_levels: 100,50,25
     time_between_runs: 1d
 ```
\ No newline at end of file
diff --git a/synapse/config/state_compressor.py b/synapse/config/state_compressor.py
index 92a0b7e533..e5742bd799 100644
--- a/synapse/config/state_compressor.py
+++ b/synapse/config/state_compressor.py
@@ -31,7 +31,7 @@ class StateCompressorConfig(Config):
             return
 
         try:
-            check_requirements("auto_compressor")
+            check_requirements("synapse_auto_compressor")
         except DependencyException as e:
             raise ConfigError from e
 
diff --git a/synapse/python_dependencies.py b/synapse/python_dependencies.py
index 7c5570976e..ef6c86fd66 100644
--- a/synapse/python_dependencies.py
+++ b/synapse/python_dependencies.py
@@ -115,7 +115,7 @@ CONDITIONAL_REQUIREMENTS = {
     # Required to use experimental `caches.track_memory_usage` config option.
     "cache_memory": ["pympler"],
     # Needs to be manually installed to use
-    "auto_compressor": ["auto_compressor"],
+    "synapse_auto_compressor": ["synapse_auto_compressor"],
 }
 
 ALL_OPTIONAL_REQUIREMENTS: Set[str] = set()
diff --git a/synapse/util/state_compressor.py b/synapse/util/state_compressor.py
index 423bbc77a3..8ef44391bb 100644
--- a/synapse/util/state_compressor.py
+++ b/synapse/util/state_compressor.py
@@ -17,7 +17,7 @@ from synapse.logging.context import defer_to_thread
 from synapse.metrics.background_process_metrics import run_as_background_process
 
 try:
-    import auto_compressor as state_compressor
+    import synapse_auto_compressor as state_compressor
 except ImportError:
     state_compressor = None
 
@@ -47,7 +47,7 @@ _VALID_POSTGRES_CONN_ARGS = {
 def setup_state_compressor(hs: "HomeServer"):
     """Schedules the state compressor to run regularly"""
 
     # Return if cannot import auto_compressor
     if not state_compressor or not hs.config.worker.run_background_tasks:
         return
@@ -47,7 +47,7 @@ _VALID_POSTGRES_CONN_ARGS = {
     """Schedules the state compressor to run regularly"""
 
-    # Return if cannot import auto_compressor
+    # Return if cannot import synapse_auto_compressor
     if not state_compressor or not hs.config.worker.run_background_tasks:
         return